@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::RecordReader;
 #ABSTRACT: Koha biblio/authority records reader
-$Koha::Contrib::Tamil::RecordReader::VERSION = '0.044';
+$Koha::Contrib::Tamil::RecordReader::VERSION = '0.045';
 use Moose;
 
 with 'MooseX::RW::Reader';
@@ -186,6 +186,10 @@ sub get_biblio_xml {
                 substr($itemsxml, index($itemsxml, "</leader>\n", 0) + 10);
         }
     }
+    if ( C4::Context->preference('Frantiq') ) {
+        require Frantiq::Pactol::BiblioNormalizer;
+        $marcxml = Frantiq::Pactol::BiblioNormalizer::process($marcxml);
+    }
     return $marcxml;
 }
 
@@ -279,7 +283,7 @@ Koha::Contrib::Tamil::RecordReader - Koha biblio/authority records reader
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSYS
 
